import React, {useState, useCallback, useEffect} from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max } from 'd3';

const csvUrl="https://gist.githubusercontent.com/DragonEnergy/43ee7bec0205d13b5cec29fb5112cf0c/raw/05f61a8ab6870e87a4f095c6c8d21af4891c27f1/residuosdecultivosgenerados.csv"; 	

const width = 960;
const height = 500;
const margin = {top: 50, right:50, bottom:50, left: 50};

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.ENERO = +d['ENERO'];
      return d;
    };
    csv(csvUrl, row).then((data) => {
      setData(data.slice(0, 12));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }
  
  console.log(data[0]); 
  console.log(data[1]);
  
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map((d) => d.Zona))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, (d) => d.ENERO)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
      {data.map((d) => (
        <rect
          key={d.ENERO}
          y={yScale(d.Zona)}
          width={xScale(d.ENERO)}
          height={yScale.bandwidth()}
        />
      ))}
      </g>
    </svg>
  );
};


const rootElement = document.getElementById('root');
  
ReactDOM.render(<App />, rootElement);